aboutsummaryrefslogtreecommitdiff
path: root/lib/Analysis/IPA/FindUnsafePointerTypes.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Analysis/IPA/FindUnsafePointerTypes.cpp')
-rw-r--r--lib/Analysis/IPA/FindUnsafePointerTypes.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/Analysis/IPA/FindUnsafePointerTypes.cpp b/lib/Analysis/IPA/FindUnsafePointerTypes.cpp
index 1058e6ed39..85b5da8ce2 100644
--- a/lib/Analysis/IPA/FindUnsafePointerTypes.cpp
+++ b/lib/Analysis/IPA/FindUnsafePointerTypes.cpp
@@ -45,11 +45,11 @@ static inline bool isSafeInstruction(const Instruction *I) {
}
// doPerMethodWork - Inspect the operations that the specified method does on
// values of various types. If they are deemed to be 'unsafe' note that the
// type is not safe to transform.
//
-bool FindUnsafePointerTypes::doPerMethodWork(Method *Meth) {
+bool FindUnsafePointerTypes::runOnMethod(Method *Meth) {
const Method *M = Meth; // We don't need/want write access
for (Method::const_inst_iterator I = M->inst_begin(), E = M->inst_end();
I != E; ++I) {
@@ -45,11 +45,11 @@ static inline bool isSafeInstruction(const Instruction *I) {
}
-// doPerMethodWork - Inspect the operations that the specified method does on
+// runOnMethod - Inspect the operations that the specified method does on
// values of various types. If they are deemed to be 'unsafe' note that the
// type is not safe to transform.